@@ -361,7 +361,7 @@ void DockView::setupWaylandIntegration()
 
     if (DockCorona *c = qobject_cast<DockCorona *>(corona())) {
         using namespace KWayland::Client;
-        PlasmaShell *interface{c->waylandDockCoronaInterface()};
+        PlasmaShell *interface {c->waylandDockCoronaInterface()};
 
         if (!interface)
             return;
@@ -1300,11 +1300,13 @@ QRect DockView::effectsArea() const
 
 void DockView::setEffectsArea(QRect area)
 {
-    if (m_effectsArea == area) {
+    QRect inWindowRect = area.intersected(QRect(0, 0, width(), height()));
+
+    if (m_effectsArea == inWindowRect) {
         return;
     }
 
-    m_effectsArea = area;
+    m_effectsArea = inWindowRect;
     emit effectsAreaChanged();
 }
 
@@ -1573,7 +1575,7 @@ void DockView::updateEffects()
             QRegion fixedMask = m_background->mask();
             fixedMask.translate(m_effectsArea.x(), m_effectsArea.y());
 
-            //! fix for KF5.32 that return empty QRegion's for the mask
+            //! fix1, for KF5.32 that return empty QRegion's for the mask
             if (fixedMask.isEmpty()) {
                 fixedMask = QRegion(m_effectsArea);
             }
